Button

Enum Button 

pub enum Button {
Show 120 variants LeftButton, RightButton, MiddleButton, SideButton1, SideButton2, Key1, Key2, Key3, Key4, Key5, Key6, Key7, Key8, Key9, Key0, Minus, Backspace, Tab, Q, W, E, R, T, Y, U, I, O, P, A, S, D, F, G, H, J, K, L, Enter, LShift, Z, X, C, V, B, N, M, Comma, Dot, Slash, RShift, LCtrl, LSuper, LAlt, Space, RAlt, RSuper, Application, RCtrl, Insert, Delete, LeftArrow, Home, End, UpArrow, DownArrow, PageUp, PageDown, RightArrow, Numpad1, Numpad2, Numpad3, Numpad4, Numpad5, Numpad6, Numpad7, Numpad8, Numpad9, Numpad0, NumpadDot, NumpadSlash, NumpadAsterisk, NumpadMinus, NumpadPlus, Esc, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, F13, F14, F15, F16, F17, F18, F19, F20, F21, F22, F23, F24, PrintScreen, VolumeMute, VolumeDown, VolumeUp, MediaNext, MediaPrevious, MediaStop, MediaPlayPause, Shift, Ctrl, Alt, Super,
}
Keyboard or mouse buttons.

Variants



LeftButton



RightButton



MiddleButton



SideButton1



SideButton2



Key1



Key2



Key3



Key4



Key5



Key6



Key7



Key8



Key9



Key0



Minus



Backspace



Tab



Q



W



E



R



T



Y



U



I



O



P



A



S



D



F



G



H



J



K



L



Enter



LShift



Z



X



C



V



B



N



M



Comma



Dot



Slash



RShift



LCtrl



LSuper



LAlt



Space



RAlt



RSuper



Application



RCtrl



Insert



Delete



LeftArrow



Home



End



UpArrow



DownArrow



PageUp



PageDown



RightArrow



Numpad1



Numpad2



Numpad3



Numpad4



Numpad5



Numpad6



Numpad7



Numpad8



Numpad9



Numpad0



NumpadDot



NumpadSlash



NumpadAsterisk



NumpadMinus



NumpadPlus



Esc



F1



F2



F3



F4



F5



F6



F7



F8



F9



F10



F11



F12



F13



F14



F15



F16



F17



F18



F19



F20



F21



F22



F23



F24



PrintScreen



VolumeMute



VolumeDown



VolumeUp



MediaNext



MediaPrevious



MediaStop



MediaPlayPause



Shift



Ctrl



Alt



Super

Implementations

Source

impl Button

pub const VARIANT_COUNT: usize = 120usize

Number of variants in the enum

Source

impl Button

pub fn kind(&self) -> ButtonKind

Source

impl Button

pub fn press(self)

Simulates a button presses.

pub fn press_recursive(self)

Simulates a button presses. Events generated by this method can be hooked.

pub fn release(self)

Simulates a button releases.

pub fn release_recursive(self)

Simulates a button releases. Events generated by this method can be hooked.

pub fn click(self)

Simulates a button click.

pub fn click_recursive(self)

Simulates a button click. Events generated by this method can be hooked.

pub fn is_pressed(self) -> bool

Returns true if the button is pressed.

pub fn is_released(self) -> bool

Returns true if the button is released.